<div class="quarto-about-trestles">
  <div class="about-entity">
    <% partial('_image.ejs.html', { about, imgOpts: {} }) %><%= about.title %>
    <% partial('_links.ejs.html', { about }) %>
  </div>
  <div class="about-contents"><%= about.body %></div>
</div>
