<% if (navbar.title || navbar.logo) { %>
  <div class="navbar-brand-container">
  <% if (navbar.logo) { %>
    <a href="<%- navbar['logo-href'] || '/index.html' %>" class="navbar-brand navbar-brand-logo">
    <img src="<%- navbar.logo %>" alt="<%- navbar['logo-alt'] || '' %>" class="navbar-logo" />
    </a>
  <% } %>

  
  <% if (navbar.title) { %>
    <a class="navbar-brand" href="/index.html">
    <span class="navbar-title"><%- navbar.title %></span>
    </a>
  <% } %>
  </div>
<% } %>
