[{"locale":"es"},{"key":"doz","names":["doz","doz.","dz","dz."],"mappings":{"default":{"default":"docena"}}},{"key":"sq","names":["sq","sq."],"mappings":{"default":{"default":"al cuadrado"}}},{"key":"ha","names":["ha"],"mappings":{"default":{"default":"hectarea"}}}]
