$wnd.rstudio.runAsyncCallback9("function bUr(a){this.a=a}\nfunction KRr(a){a.J.r4b();lMg(a.j.o)}\nfunction IRr(a){hUp(a.j);Rbi(a.a,zRr.zgc(),'loadhistory')}\nfunction JRr(a){hUp(a.j);Wbi(a.a,zRr.Dgc(),'.Rhistory',false,'savehistory')}\nfunction ZTr(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=GUr(a.a.b.a);rOp(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.p4b();break;case 2:a.a.a.J.q4b();break;case 3:IRr(a.a.a);break;case 4:JRr(a.a.a);break;case 5:KRr(a.a.a);break;case 6:a.a.a.J.s4b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nvar _VA='Load History',aWA='Save History As';sFd(3919,1,dmA);_.zgc=function NSr(){return _VA};_.Dgc=function RSr(){return aWA};sFd(3918,1,dmA);_.zgc=function gTr(){return _VA};_.Dgc=function kTr(){return aWA};sFd(3917,1,dmA);_.zgc=function BTr(){return \"Chargement de l'historique\"};_.Dgc=function FTr(){return \"Enregistrer l'historique en tant que\"};sFd(509,1,Kqy);_.jn=function aUr(){ZTr((new bUr(this)).a)};sFd(7141,1,oTx,bUr);_.ln=function cUr(){ZTr(this.a)};var cxc=dse(7141);lDx(fm)(9);\n//# sourceURL=rstudio-9.js\n")
